% Remove trend from wave spectrum measured by Datawell DWR-G4 wave buoys
% 
% function S_DT=detrend_wavespec(f,S,f_max)
% ---------------------------------------
% f is the frequency [vector]
% S is the spectral density [vector]
% f_max is the maximum frequency [double]
% ---------------------------------------
% Björkqvist et al. (2015)
function S_DT=detrend_wavespec(f,S,f_max)

S_scaled=S.*f.^2; % Scale the spectrum with f^2
bin_max=find(f<=f_max,1,'last'); % Select the bins used to calculate the trend
Trend=mean(S_scaled(1:bin_max)); % Calculate mean scaled trend
S_scaled=S_scaled-Trend; % Remove mean scaled trend
S_scaled(1:bin_max)=0; % These freq. bins did not contain any real information
S_scaled=max(S_scaled,0); % Force to positive values

S_DT=S_scaled./f.^2; % Return the de-scaled spectrum
